##  Overview
In Phase 4, the key work in SAP LeanIX is to run all agreed-upon Transformations and Impacts for the chosen transformation scenario. The advantage of working with Architecture and Road Map Planning (Previously known as the BTM module) is that you have already modeled out all possible transformations on the Application and Initiatives level. Now, you “only” need to press the button to run them, as explained in the following steps.
From this point onwards, SAP LeanIX will serve as a tool to monitor the ongoing progress of your transformation, helping you track developments and changes in this long-term journey with moving targets. In this last phase, the goals are to:
  * Run Transformations and Impacts.
  * Create transparency and communicate progress.
  * Reflect on architecture changes that have been implemented to understand what has happened and what is to come.
